@@ -6,7 +6,7 @@ use warnings;
 
 # ABSTRACT: Sugar for DBIx::Class
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 1;
 
@@ -27,16 +27,16 @@ DBIx::Class::Smooth - Sugar for DBIx::Class
 <p>
 <img src="https://img.shields.io/badge/perl-5.20+-blue.svg" alt="Requires Perl 5.20+" />
 <a href="https://travis-ci.org/Csson/p5-DBIx-Class-Smooth"><img src="https://api.travis-ci.org/Csson/p5-DBIx-Class-Smooth.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/release/CSSON/DBIx-Class-Smooth-0.0104"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/DBIx-Class-Smooth/0.0104" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=DBIx-Class-Smooth%200.0104"><img src="http://badgedepot.code301.com/badge/cpantesters/DBIx-Class-Smooth/0.0104" alt="CPAN Testers result" /></a>
-<img src="https://img.shields.io/badge/coverage-65.2%-red.svg" alt="coverage 65.2%" />
+<a href="http://cpants.cpanauthors.org/release/CSSON/DBIx-Class-Smooth-0.0105"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/DBIx-Class-Smooth/0.0105" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=DBIx-Class-Smooth%200.0105"><img src="http://badgedepot.code301.com/badge/cpantesters/DBIx-Class-Smooth/0.0105" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-76.3%-orange.svg" alt="coverage 76.3%" />
 </p>
 
 =end html
 
 =head1 VERSION
 
-Version 0.0104, released 2020-08-30.
+Version 0.0105, released 2020-09-20.
 
 =head1 SYNOPSIS
 
