@@ -10,7 +10,7 @@ use experimental qw/postderef signatures/;
 
 __PACKAGE__->load_components(qw/
     Helper::Row::RelationshipDWIM
-    Smooth::Helper::Row::Creation
+    Smooth::Helper::Row::Definition
     Smooth::Helper::Row::JoinTable
 /);
 
@@ -18,4 +18,6 @@ sub db {
     return shift->result_source->schema;
 }
 
+sub default_result_namespace { 'TestFor::DBIx::Class::Smooth::Schema::Result' }
+
 1;
