@@ -14,6 +14,9 @@ __PACKAGE__->load_components(qw/
     Helper::ResultSet::DateMethods1
     Smooth::Lookup::Operators
     Smooth::Lookup::DateTime
+    Smooth::Lookup::substring
+    Smooth::Lookup::ident
+    Smooth::Flatten::DateTime
 /);
 
 use experimental qw/postderef signatures/;
